SQUAD_DESCRIPTIONS = {
    'why were': 'Similar to "why was", "why are", "why is". The question asks about why a phenomenon or an event happens. The answer should be close to the phenomenon or the event in the context. The answer should be close to words such as "due to" and "because". The answer may start with "to".',
    'what years': 'Similar to "what year", "which year". The question asks about the time period of an event. The answer may look like "between A and B" or "from A to B" where both A and B are year numbers. The answer may also contain words such as "start in", "last until" and "end in".',
    'who said': 'The question asks about the person who made a statement. The answer should be close to the statement in the context. The answer may be before words such as "said" and "authored". The answer may be after phrases such as "delivered by" and "written by".',
    'what percent': 'Similar to "what percentage". The question asks about the percentage of a subject having a certain characteristic. The answer should be a number with a percentage mark (%). The answer may be before the word "of", followed by the subject and the characteristic.',
    'when did': 'Similar to "when does". The question asks about the time of an event. Typical patterns are "when did something happen", or "when did someone do something". The answer may follow patterns such as "something happened in ANS" or "someone did something in ANS ".',
    'where do': 'The answer should be a location. A typical pattern is "where do somebody do something". The answer may be before or after the pattern "somebody do something in ANS" or "at ANS".',
    'who is': 'The question possibly contains a person\'s name, and asks about the person\'s occupation or basic information. A typical pattern of the question is "Who is somebody". The answer may follow the pattern "somebody is ANS" or "somebody was ANS". Another possible pattern is "Who is the person that does something", and the answer may follow the pattern "ANS does something".',
    'how are': 'Similar to "how is". A typical pattern is "how are something done". The answer may start with "by", and the answer follows "something is done" in the context.',
    'what decade': 'The question asks about a decade, so typical answers include "1910s", "1920s", "1930s", "1940s", "1950s", "1960s", "1970s", "1980s", "1990s", "2000s", "2010s", "2020s", "2030s", "2040s", "2050s". The question may contain an event, and the context sentence should include the decade in which the event happened.',
    'how does': 'The question may be "how does something work", and the answer should explain the mechanism of that "something". The question may ask "how does A do B", and the answer would be "by doing something" or "do something", following "A do B" in the context.',
    'how long': 'The answer should be a time period. The question may be "how long is something" or "how long does it take to do something". The answer may be after phrases such as "it takes". The question contains "How long has something been", then the answer should start with "since" followed by a year number (e.g., "since 1990"), or start with "for" then followed by a time period (e.g., "for ten years").',
    'where was': 'Similar to "where is", "where are", "where were". The answer should be a location. The subject of the question should appear in the context. The answer may be after phrases such as "located in", "placed in".',
    'what has': 'The question may be "what has somebody done", then the answer should follow "somebody has ...". The question may be "what has something", then the answer should be one or more entities that have the property described in the question.',
    'which two': 'Similar to "what two". The answer should contain two things. The answer probably contains "and". The question may contain descriptions, and the answer should be near the descriptions in the context.', 
    'who was': 'Similar to "who were", "who are". The answer should contain a person name or an organization name. The question may contain the occupation or the accomplishment of the person. The question may contain time period. Such information should be close to the answer.', 
    'who were': 'Similar to "who was", "who are". The answer should contain a person name or an organization name. The question may contain the occupation or the accomplishment of the person. The question may contain time period. Such information should be close to the answer.',
    'where are': 'Similar to "where is", "where was", "where were". The answer should be a location. The subject of the question should appear in the context. The answer may be after phrases such as "located in", "placed in".',
    'where does': 'The answer should be a location. The question may be "where does somebody do something", so the answer may follow the pattern "somebody do something in ANS". The question may be "where does something take place", then the answer should be like "something happened in ANS" or "at ANS".',
    'what did': 'Similar to "what do", "what does". The question may be "what did somebody do". The answer may be a noun phrase followed by the verb that appeared in the question. The answer may be a verb that describes the action taken by the person in the question. If the question follows "what did somebody say", the answer should be a quote.',
    'how far': 'The answer should be a number measuring distance. The answer may end with length unit such as "kilometer", "meter", "centimeter", "millimeter", "inch", "foot", "yard", "mile", "fathom", "nautical mile", "light-year".', 
    'what organization': 'The answer should be an organization name. The question may contain certain characteristics or responsibility of the organization. In the context, the name of the organization and the characteristics will co-occur.', 
    'what does': 'Similar to "what do", "what did". The question may be "what did somebody do". The answer may be a noun phrase followed by the verb that appeared in the question. The answer may be a verb that describes the action taken by the person in the question. If the question follows "what did somebody say", the answer should be a quote.',
    'what group': 'Simlar to "which group". The answer should be the name of a group. The question will describe some actions of this group. The context mention both the group name and the action.',     
    'what would': 'The question may be "what would happen if A ". The answer should contain "would" or follow "would". A should be close to the answer.',
    'how did': 'Similar to "how do". The question may be "how did somebody die". In this case the answer may be after phrases such as "due to". The question may be "how did A become B". In this case the answer may be "by doing something".',
    'who has': 'Similar to "who had". The answer should be a person. The question may describe the characteristics of a person, or something the person possesses. This information should be close to the answer in the context.',
    'who created': 'The answer should be a person. The question asks about the person who created an item. The answer may be before words such as "created", "developed", "invented". The answer may be after phrases such as "created by", "developed by", "invented by".', 
    'how many': 'The answer should be a number. The question should contain a noun phrase after "how many" and the answer may be directly before the noun phrase in the context. The question may also contain a condition and this condition should also appear near the answer.', 
    'what name': 'The answer should be a name or a noun phrase. The question typically asks about the name given to someone or something.', 
    'what types': 'Similar to "what type", "what kind". The answer may be adjectives that describe certain types of the subject. The question may contain certain capabilities, and the answer should be near these capabilities in the context.',
    'what two': 'Similar to "which two". The answer should contain two things, probably linked by "and". The question may contain descriptions, and the answer should be near the descriptions in the context.', 
    'which city': 'Similar to "what city". The answer should be a city. The question may contain an event held in this city or some characteristic of the city. This information should appear near the answer. Major cities in the world includes Tokyo, Delhi, Shanghai, São Paulo, Mexico City, Kairo, Mumbai, Osaka, Buenos Aires, New York City, Los Angeles.', 
    'who are': 'Similar to "who were", "who was", "who is". The answer should contain a person name or an organization name. The question may contain the occupation or the accomplishment of the person. The question may contain time period. Such information should be close to the answer.',
    'how is': 'Similar to "how are", "how were", "how was". A typical pattern is "how are something done". The answer may start with "by", and the answer follows "something is done" in the context.',
    'what event': 'The answer should be an event. A typical pattern is "what event led to X" or "what event started X". In this case, the answer may be before phrases such as "led to". Another possible question pattern is "what event happened during" or "what event occured during". In this case, the answer should be near the time range provided in the question.',
    'what are': 'Similar to "what is". This is a generic "what" question. The answer should be a noun or a noun phrase.', 
    'what century': 'The question asks about century, so the typical answer includes the 20th century, the 19th century, the first century, etc. The question may contain an event. In this case the event should be close to the answer in the context.', 
    'what area': 'The answer should be an area or a location. The question may ask about where an event happened or where a person lives in.', 
    'whom did': 'Similar to "who did". The answer should be a person. The question may contain the name of another person, and the context should describe an event happened between these two people.', 
    'why was': ' Similar to "why were", "why are", "why is". The question asks about why a phenomenon or an event happens. The answer should be close to the phenomenon or the event in the context. The answer should be close to words such as "due to" and "because". The answer may start with "to".', 
    'who wrote': 'The answer should be a person. The question should include the name of a book, a song or an article. The answer should be after phrases such as "written by", "lyrics by", or before phrases such as "wrote", "authored".', 
    'why are': ' Similar to "why was", "why were", "why is". The question asks about why a phenomenon or an event happens. The answer should be close to the phenomenon or the event in the context. The answer should be close to words such as "due to" and "because". The answer may start with "to".',
    'where is': 'The answer should be location, for example the name of a city or a country. The question can be asking about physical location of an object or a building. The question can also be asking about the place where an event happened.',
    'how old': 'The answer should be a number. The question may be asking about a person\' age when some achievement is made. The answer should be close to phrases such as "at age ANS" or " ANS years old".', 
    'when is': 'The answer should be a date. The question may ask about the specific date of a holiday. The answer may be close to phrases such as "falls on". The question may be asking about the release date of a movie or a game. The answer may be after phrases such as "released on".',
    'what caused': 'The question asks about the cause of a phenomenon or an event. The answer should be after phrases such as "due to", "caused by". The answer may be before phrases such as "lead to".', 
    'who did': 'Similar to "whom did". The answer should be a person. The question may contain the name of another person, and the context should describe an event happened between these two people.',
    'where did': 'The answer should be a place. The question may describe an event. The context sentence should also describe this event. The answer may start with "in" or "at".', 
    'what happened': 'The question may ask about what happened on a certain date, or what happened to someone. Find the date or person in the context.', 
    'what state': 'The answer should be a state. A state is a polity under a system of governance. States in the United States include: Alabama, Alaska, American Samoa, Arizona, Arkansas, California, Colorado, Connecticut, Delaware, District of Columbia, Florida, Georgia, Guam, Hawaii, Idaho, Illinois, Indiana, Iowa, Kansas, Kentucky, Louisiana, Maine, Maryland, Massachusetts, Michigan, Minnesota, Mississippi, Missouri, Montana, Nebraska, Nevada, New Hampshire, New Jersey, New Mexico, New York, North Carolina, North Dakota, Northern Mariana Islands, Ohio, Oklahoma, Oregon, Pennsylvania, Puerto Rico, Rhode Island, South Carolina, South Dakota, Tennessee, Texas, Utah, Vermont, Virgin Islands, Virginia, Washington, West Virginia, Wisconsin, Wyoming.', 
    'what kind': 'Similar to "what types", "what type". The answer may be adjectives that describe certain types of the subject. The question may contain certain capabilities, and the answer should be near these capabilities in the context.',
    'what time': 'The answer should be an exact time point. The question may ask about the time that an event starts or ends. The answer typically starts with "at".', 
    'what famous': 'The answer may be a famous person or location. The question may describe something happened to the person or at the location.', 
    "what's the": 'Similar to "what are", "what is". The answer should be noun or noun phrase. The question may follow the pattern "What is A", then the answer may be after "A is ..." in the context. The question may follow the pattern "What is A that B", where B is a description. In this case, the answer should be an entity of type A, and should appear near the mention of B in the context.', 
    'what day': 'Similar to "what date". The answer should be a date. The question may contain an event, so the answer should be the date when the event happened. The answer could be close to phrases such as "take place" and "happen". The question may contain the name of a festival or public holiday. The answer may be after phrases "celebrated on".', 
    'what is': 'Similar to "what\'s the", "what are". The answer should be noun or noun phrase. The question may follow the pattern "What is A", then the answer may be after "A is ..." in the context. The question may follow the pattern "What is A that B", where B is a description. In this case, the answer should be an entity of type A, and should appear near the mention of B in the context.', 
    'what company': 'The answer should be the name of a company. The question may describe some product released by the company or some achievements made by the company. The context sentence should mention these products or achievements. The question may describe a famous person and asks what company the person works for.', 
    'what were': 'Similar to "what\'s the", "what are", "what is". The answer should be noun or noun phrase. The question may follow the pattern "What is A", then the answer may be after "A is ..." in the context. The question may follow the pattern "What is A that B", where B is a description. In this case, the answer should be an entity of type A, and should appear near the mention of B in the context.', 
    'why do': 'Similar to "why did". The question may follow the pattern "why do A do B". The answer may be after the pattern "A do B because ANS" or "A do be due to ANS".', 
    'what new': 'The answer should be a noun or noun phrase. The answer may be related to products, movies, games or features. The question may contain a specific date, so the answer is close to that date in the context.',
    'what date': 'Similar to "what day". The answer should be a date. The question may contain an event, so the answer should be the date when the event happened. The answer could be close to phrases such as "take place" and "happen". The question may contain the name of a festival or public holiday. The answer may be after phrases "celebrated on".',
    'what do': 'The question can be "what do A do", then the answer should be verbor an occupation. The question can also be "what do A B" where A is the subject and \B is a verb. The answer should be after B or its synonym in the context.',
    'what color': 'The answer should be the color of an item in the question. Common colors include red, yellow, blue, brown, orange, green, violet, black, carnation pink, yellow orange, blue green, red violet, red orange, yellow green, blue violet, white, violet red, dandelion, cerulean, apricot, scarlet, green yellow, indigo, gray.', 
    'which group': 'Similar to "what group". The answer should be the name of a group. The question will describe some actions of this group. The context mention both the group name and the action.', 
    'what country': 'Similar to "which country". The answer should be a country name. The question will describe something that this country possesses or some event that happens in the country. The answer may be after the word "in". The answer may be among: China, India, United States, Indonesia, Pakistan, Nigeria, Brazil, Bangladesh, Russia, Mexico, Japan, Philippines, Ethiopia, Egypt, Congo, Vietnam, Iran, Turkey, Germany, Thailand, France, United Kingdom, Italy, Tanzania, Burma, South Africa, Kenya, South Korea, Spain, Colombia.',
    'how can': 'The question can be "how can A be B" where B is an adjective, or "How can A do B", where B is a verb. The answer may follow the pattern "by doing something", or after phrases such as "because" and "due to".', 
    'what have': 'This question is generic. The question can be "what have somebody done", then the context would describe some actions taken by this person or a subject related to the action.', 
    'where can': 'The answer should be a location. The question asks about the place a person can do something, or asks about the place where a special item can be found.', 
    'what period': 'The answer should be a time period. The question may contain an event that happened during this period. The answer may be after phrases such as "during", "at", "in".', 
    'which year': 'Similar to "what years", "what year". The question asks about the time period of an event. The answer should be one or more year numbers. The answer may look like "between A and B" where both A and B are year numbers. The answer could also contain words such as "start in", "last until" and "end in".', 
    'when was': 'Similar to "when were". The answer should be a time period. The question may look like "when was X" and X is the name of an event. The answer may be after words such as "took place" and "happened". The answer may start with "in", "on", "at".',
    'what other': 'The question may contain the word "besides". The noun phrase after "besides" should not be included in the answer, but the answer should be close to this noun phrase in the context.',
    'what happens': 'The question may contain a specific date, place or condition. The answer would describe an event that will happen when the condition is satisfied, on the specifided date, or at the specified place.', 
    'was the': 'If the question contains "or", then this is a selective question, and the answer should be one of the two options in the question.', 
    'what was': 'Similar to "what are". This is a generic "what" question. The answer should be a noun or a noun phrase.',
    'which of': 'Similar to "what sort". The noun phrase after "which of" should limit the answer type. The answer should fall into the category specified by this noun phrase. The question will also contain a condition, so the answer should satisfy this condition in the context.',
    'when were': 'Similar to "when was". The answer should be a time period. The question may look like "when was X" and X is the name of an event. The answer may be after words such as "took place" and "happened". The answer may start with "in", "on", "at".',
    'what sort': 'Similar to "which of". The noun phrase after "which of" should limit the answer type. The answer should fall into the category specified by this noun phrase. The question will also contain a condition, so the answer should satisfy this condition.',
    'what city': 'Similar to "which city". The answer should be a city. The question may contain an event held in this city or some characteristic of the city. This information should appear near the answer. Major cities in the world includes Tokyo, Delhi, Shanghai, São Paulo, Mexico City, Kairo, Mumbai, Osaka, Buenos Aires, New York City, Los Angeles.', 
    'what year': 'Similar to "what years", "which year". The question asks about the time period of an event. The answer should be one or more year numbers. The answer could also contain words such as "start in", "last until" and "end in".',
    'what month': 'The question asks about the specific month that an event happened. The answer should be after word "in". The answer should be among January, February, March, April, May, June, July, August, September, October, November, December.',
    'why is': ' Similar to "why was", "why are", "why were". The question asks about why a phenomenon or an event happens. The answer should be close to the phenomenon or the event in the context. The answer should be close to words such as "due to" and "because". The answer may start with "to".',
    'what part': 'The noun phrase after "what part of" is critical. The answer should be a component of the noun phrase. The question may specify what the component looks like or is capable to do. The answer should be close to these descriptions in the context.', 
    'what term': 'The answer should be a noun phrase or a name. The question will ask about the terminology (or name) used to describe a collection of things, or used as a common name. The answer may be after phrase "known as" or in parentheses.', 
    'how was': 'Similar to "how are", "how is", "how was". A typical pattern is "how are something done". The answer may start with "by", and the answer follows "something is done" in the context.', 
    'how were': 'Similar to "how are", "how was", "how is". A typical pattern is "how are something done". The answer may start with "by", and the answer follows "something is done" in the context.',
    'how do': 'Similar to "how did". The question may be "how did somebody die". In this case the answer may be after phrases such as "due to". The question may be "how did A become B". In this case the answer may be "by doing something".',
    'who led': 'The answer should be the name of a person. The question may be asking about a war or an event. The answer should be close to this war or event. The answer may be after phrases such as "led by" or "under".', 
    'which country': 'Similar to "what country". The answer should be a country name. The question will describe something that this country possesses or some event that happens in the country. The answer may be after the word "in". The answer may be among: China, India, United States, Indonesia, Pakistan, Nigeria, Brazil, Bangladesh, Russia, Mexico, Japan, Philippines, Ethiopia, Egypt, Congo, Vietnam, Iran, Turkey, Germany, Thailand, France, United Kingdom, Italy, Tanzania, Burma, South Africa, Kenya, South Korea, Spain, Colombia.', 
    'when does': 'Similar to "when did". The question asks about the time of an event. Typical patterns are "when did something happen", or "when did someone do something". The answer may follow patterns such as "something happened in ANS" or "someone did something in ANS ".',
    'where were': 'Similar to "where is", "where are", "where was". The answer should be a location. The subject of the question should appear in the context. The answer may be after phrases such as "located in", "placed in".', 
    'what political': 'The answer should be a noun phrase. The question may be asking about a political party, theory, or event.', 
    'what religion': 'The answer should be the name of a religous group. The answer may be among: Christianity, Islam, Hinduism, Buddhism, Folk religion, Taoism, Shinto, Sikhism, Judaism, Confucianism, Spiritism, Korean shamanism, Caodaism, Baháʼí Faith, Jainism, Cheondoism, Hoahaoism, Tenriism.', 
    'why did': 'Similar to "why do". The question may follow the pattern "why do A do B". The answer may be after the pattern "A do B because ANS" or "A do be due to ANS".', 
    'what type': 'Similar to "what types", "what kind". The answer may be adjectives that describe certain types of the subject. The question may contain certain capabilities, and the answer should be near these capabilities in the context.',
    'what language': 'The answer should be the name of a language. The question may be asking about what language does a person speak or what language is used in a country. The answer should be close to the person or the country in the context. The answer may be among: Mandarin Chinese, Spanish, English, Hindi, Bengali, Portuguese, Russian, Japanese, Western Punjabi, Marathi, Telugu, Wu Chinese, Turkish, Korean, French, German, Vietnamese, Tamil, Yue Chinese, Urdu, Javanese, Italian, Egyptian Arabic, Gujarati, Iranian Persian, Bhojpuri, Min Nan Chinese, Hakka Chinese, Jin Chinese, Hausa.', 
    'who had': 'Similar to "who has". The answer should be a person. The question may describe the characteristics of a person, or something the person possesses. This information should be close to the answer in the context.', 
    'what percentage': 'Similar to "what percent". The question asks about the percentage of a subject having a certain characteristic. The answer should be a number with a percentage mark (%). The answer may be before the word "of", followed by the subject and the characteristic.', 
    'what can': 'The answer should be a noun phrase or a verb phrase. The question may be asking about what can somebody or something do in some circumstances, then the answer should be a verb phrase or some action. The question may be asking about what can somebody use to do something, then the answer should be a noun phrase. The question may be asking about what can somebody achieve, then the answer should be a noun phrase describing some achievement.', 
    'how much': ' The answer should be a number. If the question contains "money", "purchase", "buy" or "cost", the answer should be the amount of money, and may include symbols "$", "¥", "€", or include currency unit such as "dollar", "yen", "shilling", "ruble", "pound". The question may also be asking about relative growth or decrease. If the question starts with "how much of", or contain words such as "decrease", "grow", "increase", the answer should be a number with a percentage mark (%).',
}
